#
# spec file for package qhull
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sonum   6 
%define ver     2012.1
%define libver  6_3_1_1494

Name:           qhull
Version:        %{ver}.2
Release:        14.3
Url:            http://www.qhull.org
Source0:        %{name}-%{ver}-src.tgz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  gcc-c++
Requires:       libqhull%{sonum}-%{libver} = %{version}
Summary:        Computing convex hulls, Delaunay triangulations and Voronoi diagrams
License:        Qhull
Group:          System/Libraries

%description
Qhull computes the convex hull, Delaunay triangulation, Voronoi diagram, 
halfspace intersection about a point, furthest-site Delaunay triangulation, 
and furthest-site Voronoi diagram. The source code runs in 2-d, 3-d, 4-d, 
and higher dimensions. Qhull implements the Quickhull algorithm for computing 
the convex hull. It handles roundoff errors from floating point arithmetic. It 
computes volumes, surface areas, and approximations to the convex hull.

Qhull does not support constrained Delaunay triangulations, triangulation of 
non-convex surfaces, mesh generation of non-convex objects, or medium-sized 
inputs in 9-D and higher.


%package -n libqhull%{sonum}-%{libver}
Summary:        Computing convex hulls, Delaunay triangulations and Voronoi diagrams
Group:          Development/Libraries/Other

%description -n libqhull%{sonum}-%{libver}
Qhull computes the convex hull, Delaunay triangulation, Voronoi diagram,
halfspace intersection about a point, furthest-site Delaunay triangulation,
and furthest-site Voronoi diagram. The source code runs in 2-d, 3-d, 4-d,
and higher dimensions. Qhull implements the Quickhull algorithm for computing
the convex hull. It handles roundoff errors from floating point arithmetic. It
computes volumes, surface areas, and approximations to the convex hull.

Qhull does not support constrained Delaunay triangulations, triangulation of
non-convex surfaces, mesh generation of non-convex objects, or medium-sized
inputs in 9-D and higher.

%package devel
Summary:        Development and documentation files for qhull
Group:          Development/Libraries/Other
Requires:       qhull = %{version}

%description devel
Qhull computes the convex hull, Delaunay triangulation, Voronoi diagram,
halfspace intersection about a point, furthest-site Delaunay triangulation,
and furthest-site Voronoi diagram. The source code runs in 2-d, 3-d, 4-d,
and higher dimensions. Qhull implements the Quickhull algorithm for computing
the convex hull. It handles roundoff errors from floating point arithmetic. It
computes volumes, surface areas, and approximations to the convex hull.

Qhull does not support constrained Delaunay triangulations, triangulation of
non-convex surfaces, mesh generation of non-convex objects, or medium-sized
inputs in 9-D and higher.


%prep
%setup -q -n %{name}-%{ver}

%build
cd build
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DMAN_INSTALL_DIR=%{_mandir}/man1/ -DLIB_INSTALL_DIR=%{_libdir} -DDOC_INSTALL_DIR=%{_docdir}/%{name} -DCMAKE_SKIP_INSTALL_RPATH=ON ..
make %{?jobs:-j%jobs}

%install
cd build
make DESTDIR=$RPM_BUILD_ROOT install
cd ..
rm $RPM_BUILD_ROOT%{_libdir}/*.a
mkdir $RPM_BUILD_ROOT%{_docdir}/%{name}/devel
mv $RPM_BUILD_ROOT%{_docdir}/%{name}/*.* $RPM_BUILD_ROOT%{_docdir}/%{name}/devel
cp Announce.txt src/Changes.txt README.txt REGISTER.txt $RPM_BUILD_ROOT%{_docdir}/%{name}
mkdir $RPM_BUILD_ROOT%{_docdir}/%{name}-%{libver}
cp COPYING.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{libver}

%post -n libqhull%{sonum}-%{libver} -p /sbin/ldconfig

%postun -n libqhull%{sonum}-%{libver} -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_bindir}/qconvex*
%{_bindir}/qdelaunay*
%{_bindir}/qhalf*
%{_bindir}/qhull*
%{_bindir}/qvoronoi*
%{_bindir}/rbox*
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/Announce.txt
%{_docdir}/%{name}/Changes.txt
%{_docdir}/%{name}/README.txt
%{_docdir}/%{name}/REGISTER.txt

%files -n libqhull%{sonum}-%{libver}
%defattr(-,root,root)
%{_libdir}/libqhull_p.so.*
%{_libdir}/libqhull.so.*
%dir %{_docdir}/%{name}-%{libver}
%{_docdir}/%{name}-%{libver}/COPYING.txt

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/libqhull_p.so
%{_libdir}/libqhull.so
%{_mandir}/man1/*
%{_docdir}/%{name}/devel

%changelog
* Mon Sep  1 2014 hrvoje.senjan@gmail.com
- Change license to Qhull - it is now recognized by spdx.org
* Mon Aug  5 2013 hrvoje.senjan@gmail.com
- enable CMAKE_SKIP_INSTALL_RPATH option so RPATH is ommited from
  install tree
* Thu Mar  8 2012 cfarrell@suse.com
- license update: SUSE-Qhull
  Use SUSE- proprietary prefix until Qhull (incidentially, also the Fedora
  designation for the license) is accepted upstream at spdx.org
* Thu Feb 23 2012 saschpe@suse.de
- Add some detail about the version update to 2012.1
* Wed Feb 22 2012 pgajdos@suse.com
- updated to 2012.1.2 (6_3_1_1494)
  - upstreamed liblibname.patch
* Tue Feb 21 2012 pgajdos@suse.com
- updated to 2012.1.1 (6_3_1_1490):
  - Require option 'Qz' for Delaunay triangulation/Voronoi diagram
    of cocircular/cospherical points [D. Sheehy]
  - qh_errexit: Do not call qh_printsummary or qh_printstats on qh_ERRinput
  - Change error QH6227 (all degenerate) from qh_ERRinput to qh_ERRprec
  - Change error QH6159 (ID overflow) from qh_ERRinput to qh_ERRqhull
  - eg/q_eg, q_egtest, q_test: Run if qconvex is in $PATH [M. Atzeri]
* Mon Jan 30 2012 pgajdos@suse.com
- updated to 2012.1:
  - Add config to distribution
  - Add testqset to config build
  - config/bootstrap.sh copies program files into src/libqhull
* Mon Nov 28 2011 idoenmez@suse.de
- Fix duplicate files
* Mon Sep 19 2011 pgajdos@suse.com
- updated to 2011.1:
  * Remove deprecated libqhull/qhull.h. Use libqhull/libqhull.h instead.
  * QhullFacet: Added isSimplicial, isTopOrient, isTriCoplanar, isUpperDelaunay
  * Added Qhull::defineVertexFacetNeighbors() for facetNeighbors of vertices.
    Automatically called for facet merging and Voronoi diagrams
    Do not print QhullVertex::facetNeighbors is !facetNeighborsDefined()
  * Add Fixup identifiers
  * QhullError: Add copy constructor, assignment operator, and destructor
  * Add throw() specifiers to RoadError and QhullError
  * Renamed RoadError::defined() to RoadError::isDefined()
  * Add #error to Qhull.h if qh_QHpointer is not defined
  * etc. see Changes.txt
* Tue Jul 20 2010 johannesobermayr@gmx.de
- initial package
  * next branch of git://gitorious.org/qhull/qhull.git
- susepatches.diff
  * fix build breakage caused by serious compiler warnings
